==> zubair-react-form-builder-1.0.2.tgz: package/README.md <==
# React From Builder

## Dependencies
1. react
2. jquery,
3. jquery ui
4. jquery-ui-timepicker-addon
5. twitter bootstrap


## FormContainer Props
1. custom : Array
2. onSave(form) : Function

## ToolBox Props
1. custom : Array

## Example
You can pass custom components to the form builder
<pre>
const myCustoms = [
    {
        container : &lt ContainerComponent/&gt,
        preview : &lt PreviewComponent/&gt,
        toolbox : {
            title : 'Component',
            icon : 'fa fa-user',
            name : 'CUSTOM_COM'
        },
        states : {
            toolType: 'CUSTOM_COM',
            num1 : 1,
            num2 : 2
        }
    }
]

Simply pass myCustoms to
&lt FormContainer onSave={YOUR_METHOD} custom={ myCustoms } /&gt
&lt ToolBox custom={ myCustoms } /&gt
</pre>

## Required Props Methods Of Custom Component

1. this.props.changeState(state, this.props.index)

2. this.props.removeField(index)

## Example Props Methods

<pre>
        // on change state
        changeValue(stateFor, value){
            switch (stateFor){
                case "TITLE" :
                    this.setState( { title : value } )
                    break;
                default:
                    return;
            };
            setTimeout(() => {
                return this.props.changeState(this.state, this.props.index);
            }, 0)
        }
        
       
        <input 
            value={this.state.value}
            onChange={(e) => this.changeValue('TITLE', e.target.value)} />
        
         // on remove field   
        <span 
            className='pull-right cross' 
            onClick={() => this.props.removeField(this.props.index)}>x</span>
            
</pre>

==> zubair-react-form-builder-1.0.3.tgz: package/README.md <==
# React From Builder

## Dependencies
1. react
2. jquery,
3. jquery ui
4. jquery-ui-timepicker-addon
5. twitter bootstrap


## FormContainer Props
1. custom : Array
2. onSave(form) : Function 

// Note OnSave Props also Visible Save Button on &lt;FormContainer /&gt;

## ToolBox Props
1. custom : Array

## Example
You can pass custom components to the form builder

<pre>
const myCustoms = [
    {
        container : &lt ContainerComponent/&gt,
        preview : &lt PreviewComponent/&gt,
        toolbox : {
            title : 'Component',
            icon : 'fa fa-user',
            name : 'CUSTOM_COM'
        },
        states : {
            toolType: 'CUSTOM_COM',
            num1 : 1,
            num2 : 2
        }
    }
]

class App extends React.Component {
    render(){
        /* Simply pass myCustoms to */
        &lt;div className="app"/&gt;
            &lt;div className="row"/&gt;
                &lt;div className="col-8"/&gt;
                    &lt;FormContainer onSave={YOUR_METHOD} custom={ myCustoms } /&gt;
                &lt;/div&gt;
                &lt;div className="col-8"/&gt;
                    &lt ToolBox custom={ myCustoms } /&gt;
                 &lt;/div&gt;
            &lt/div/&gt
        &lt/div/&gt
    }
}
</pre>

## Required Props Methods Of Custom Component

1. this.props.changeState(state, this.props.index)

2. this.props.removeField(index)

## Example Props Methods

<pre>
        // on change state
        changeValue(stateFor, value){
            switch (stateFor){
                case "TITLE" :
                    this.setState( { title : value } )
                    break;
                default:
                    return;
            };
            setTimeout(() => {
                return this.props.changeState(this.state, this.props.index);
            }, 0)
        }
        
       
        <input 
            value={this.state.value}
            onChange={(e) => this.changeValue('TITLE', e.target.value)} />
        
         // on remove field   
        <span 
            className='pull-right cross' 
            onClick={() => this.props.removeField(this.props.index)}>x</span>
            
</pre>
